/** Le istanze di questa classe rappresentano prismi a base rettangolare, con misure in centimetri.
 *  Le dimensioni del prisma sono riordinate in ordine non decrescente.
 * 
 * @author Paolo Boldi
 *
 */
public class Prisma implements Comparable<Prisma> {
	/** La prima misura, in centimetri. */
	protected double x;

	/** La seconda misura, in centimetri. */
	protected double y;
	
	/** La terza misura, in centimetri. */
	protected double z;
	
	public Prisma(double x, double y, double z) {
		this.x = Math.min(Math.min(x, y), z);
		this.z = Math.max(Math.max(x, y), z);
		this.y = x + y + z - this.x - this.z;
	}
	
	/** Costruisce un prisma a base quadrata.
	 * 
	 * @param latoBase il lato della base, in centimetri.
	 * @param altezza l'altezza, in centimetri.
	 */
	public Prisma(double latoBase, double altezza) {
		this(latoBase, latoBase, altezza);
	}
	
	public Prisma(double lato) {
		this(lato, lato);
	}
	
	public Prisma() {
		this(10.0);
	}
	
	public double x() {
		return x;
	}
	
	public double y() {
		return y;
	}
	
	public double z() {
		return z;
	}
	
	/** Restituisce il volume del prisma in centimetri cubi.
	 * 
	 * @return il volume del prisma.
	 */
	public double volume() {
		return x * y * z;
	}
	
	public double superficieEsterna() {
		return 2 * (x * y + x * z + y * z);
	}
	
	@Override
	public String toString() {
		return x + "x" + y + "x" + z + " cm.";
	}
	
	@Override
	public boolean equals(Object o) {
		if (o instanceof Prisma) {
			Prisma p = (Prisma)o;
			return x == p.x && y == p.y && z == p.z;
		} else
			return false;
	}

	@Override
	public int compareTo(Prisma p) {
		double volume = this.volume();
		double volumep = p.volume();
		if (volume < volumep) return -1;
		else if (volume > volumep) return 1;
		else return 0;
	}
	
	
	
	
}
